@@ -10,9 +10,9 @@ License:
 """
 from dataclasses import dataclass
 
-from illumio.util import ModifiableObject
+from illumio.util import MutableObject
 
 
 @dataclass
-class Vulnerability(ModifiableObject):
+class Vulnerability(MutableObject):
     score: int = None
